# Invoicelineitems


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**description** | **str** | Invoice line item transaction name. | [optional] 
**amount** | **float** | Billed amount for line item. | [optional] 
**credit_coupon_code** | **str** | Discount coupon associated with the invoice for any account or service credits. | [optional] 
**rate** | **float** | Price per unit. | [optional] 
**units** | **float** | Total number of units of usage. | [optional] 
**product_name** | **str** | The name of the product. | [optional] 
**product_group** | **str** | The broader classification of the product (e.g., `Compute` or `Full-Site Delivery`). | [optional] 
**region** | **str** | The geographical area applicable for regionally based products. | [optional] 
**usage_type** | **str** | The unit of measure (e.g., `requests` or `bandwidth`). | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


